@@ -25,11 +25,23 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <gtk/gtk.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 
 G_BEGIN_DECLS
 
+/**
+ * NOTIFY_EXPIRES_DEFAULT:
+ *
+ * The default expiration time on a notification.
+ */
 #define NOTIFY_EXPIRES_DEFAULT -1
+
+/**
+ * NOTIFY_EXPIRES_NEVER:
+ *
+ * The notification never expires. It stays open until closed by the calling API
+ * or the user.
+ */
 #define NOTIFY_EXPIRES_NEVER    0
 
 #define NOTIFY_TYPE_NOTIFICATION         (notify_notification_get_type ())
@@ -45,7 +57,9 @@ typedef struct _NotifyNotificationPrivate NotifyNotificationPrivate;
 
 struct _NotifyNotification
 {
+        /*< private >*/
         GObject                    parent_object;
+
         NotifyNotificationPrivate *priv;
 };
 
@@ -57,51 +71,55 @@ struct _NotifyNotificationClass
         void            (*closed) (NotifyNotification *notification);
 };
 
-/*
- * Notification urgency levels.
+
+/**
+ * NotifyUrgency:
+ * @NOTIFY_URGENCY_LOW: Low urgency. Used for unimportant notifications.
+ * @NOTIFY_URGENCY_NORMAL: Normal urgency. Used for most standard notifications.
+ * @NOTIFY_URGENCY_CRITICAL: Critical urgency. Used for very important notifications.
+ *
+ * The urgency level of the notification.
  */
 typedef enum
 {
         NOTIFY_URGENCY_LOW,
         NOTIFY_URGENCY_NORMAL,
-        NOTIFY_URGENCY_CRITICAL,
+        NOTIFY_URGENCY_CRITICAL
 
 } NotifyUrgency;
 
+/**
+ * NotifyActionCallback:
+ * @notification:
+ * @action:
+ * @user_data:
+ *
+ * An action callback function.
+ */
 typedef void    (*NotifyActionCallback) (NotifyNotification *notification,
                                          char               *action,
                                          gpointer            user_data);
 
+/**
+ * NOTIFY_ACTION_CALLBACK:
+ * @func: The function to cast.
+ *
+ * A convenience macro for casting a function to a #NotifyActionCallback. This
+ * is much like G_CALLBACK().
+ */
 #define NOTIFY_ACTION_CALLBACK(func) ((NotifyActionCallback)(func))
 
 GType               notify_notification_get_type             (void);
 
 NotifyNotification *notify_notification_new                  (const char         *summary,
                                                               const char         *body,
-                                                              const char         *icon,
-                                                              GtkWidget          *attach);
-
-NotifyNotification *notify_notification_new_with_status_icon  (const char         *summary,
-                                                               const char         *body,
-                                                               const char         *icon,
-                                                               GtkStatusIcon      *status_icon);
+                                                              const char         *icon);
 
 gboolean            notify_notification_update                (NotifyNotification *notification,
                                                                const char         *summary,
                                                                const char         *body,
                                                                const char         *icon);
 
-void                notify_notification_attach_to_widget      (NotifyNotification *notification,
-                                                               GtkWidget          *attach);
-
-void                notify_notification_attach_to_status_icon (NotifyNotification *notification,
-                                                               GtkStatusIcon      *status_icon);
-
-void                notify_notification_set_geometry_hints    (NotifyNotification *notification,
-                                                               GdkScreen          *screen,
-                                                               gint                x,
-                                                               gint                y);
-
 gboolean            notify_notification_show                  (NotifyNotification *notification,
                                                                GError            **error);
 
@@ -117,7 +135,7 @@ void                notify_notification_set_urgency           (NotifyNotificatio
 void                notify_notification_set_icon_from_pixbuf  (NotifyNotification *notification,
                                                                GdkPixbuf          *icon);
 void                notify_notification_set_image_from_pixbuf (NotifyNotification *notification,
-                                                               GdkPixbuf          *image);
+                                                               GdkPixbuf          *pixbuf);
 
 void                notify_notification_set_hint_int32        (NotifyNotification *notification,
                                                                const char         *key,
@@ -143,6 +161,13 @@ void                notify_notification_set_hint_byte_array   (NotifyNotificatio
                                                                const guchar       *value,
                                                                gsize               len);
 
+void                notify_notification_set_hint              (NotifyNotification *notification,
+                                                               const char         *key,
+                                                               GVariant           *value);
+
+void                notify_notification_set_app_name          (NotifyNotification *notification,
+                                                               const char         *app_name);
+
 void                notify_notification_clear_hints           (NotifyNotification *notification);
 
 void                notify_notification_add_action            (NotifyNotification *notification,
